@@ -1,6 +1,7 @@
 from .scalar_resolver import ScalarResolver
-from ...functional.util import string_to_accessors, select
-from ...functional.parse_grammar import parse_resolver_args_and_value
+from ...functional.util import select
+from ...grammar.scalar_grammar import parse_resolver_args_and_value
+from ...grammar.accessor_grammar import parse_accessor
 
 class SelectResolver(ScalarResolver):
     """
@@ -10,6 +11,6 @@ class SelectResolver(ScalarResolver):
 
     def resolve(self, args_and_value, root_node, trace, **_):
         args, value = parse_resolver_args_and_value(args_and_value, n_args=1)
-        accessors = string_to_accessors(args[0])
+        accessors = parse_accessor(args[0])
         node = select(root_node=value, accessors=accessors, trace=trace, source_id=root_node.source_id)
         return node
\ No newline at end of file
